@@ -104,7 +104,7 @@ class AbstractGeneratorXml(object):
             self.cadena_original_value = self.get_cadena_original(self.get_xml())
             logging.info('LA CADENA ORIGINAL DEL XML')
             digest = self.algoritmoSha.new()
-            digest.update(self.cadena_original_value)
+            digest.update(bytes(self.cadena_original_value))
             signer = PKCS1_v1_5.new(key)
             sign = signer.sign(digest)
             sello = b64encode(sign)
